##  Step 1. Run Implemented Transformation
As soon as important project milestones are achieved, make sure to reflect this in the architecture. With the SAP LeanIX Architecture and Road Map Planning, you can apply the planned impacts to your architecture by executing the Transformations.
![Execute implemented Transformations to keep track.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c56ac7a44101488acb28dcb253aa3_LowRes.png)
Execute implemented Transformations to keep track
